#
# Makefile for GNU Chess
#
# Copyright (c) 1992 Free Software Foundation
#
# This file is part of GNU CHESS.
#
# GNU Chess is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# GNU Chess is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with GNU Chess; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
#

#
# This makefile is for Microsoft C/C++ compiler version 7.00 (MS-DOS).
# It was made by Martin Liversage (martin@iris.kth.dk).
#

#
# gnuchess is a curses-based chess.
# gnuchesn is a fancy-display-curses-based chess.
# gnuchesr is a plain dumb-terminal chess (but with full variation output)
# gnuchesc is suitable for chesstool use (mimics /usr/games/chess output)
#

# The version number of this GNU and Xboard release
VERS = 4.0

# Where language description, our book, and the persistent hash live.
LIBDIR = .

#compile options for gnuchess
# -DAG[0-4]  selects a set of values for SpaceBonus tables
# -DQUIETBACKGROUND don't print post information in background ( easy OFF)
# -DNOMEMSET if your machine does not support memset
# -DNOMATERIAL don't call it a draw when no pawns and both sides < rook
# -DNODYNALPHA don't dynamically adjust alpha
# -DHISTORY use history killer hueristic
# -DKILLT use killt killer hueristic
# -DHASGETTIMEOFDAY use gettimeofday for more accurate timing
# -DCLIENT create client version for use with ICS
# -DNOSCORESPACE don't use Scorespace heuristic
# -DOLDXBOARD don't generate underpromote moves
# -DGNU3 don't generate underpromote moves
# -DLONG64 if you have 64bit longs
# -DSYSV   if you are using SYSV
# -DCACHE  Cache static evaluations
# -DE4OPENING always open e4 if white and respond to e4 with e5 if black
# -DQUIETBOOKGEN Don't print errors while loading a book or generating a binbook
# -DSEMIQUIETBOOKGEN Print less verbose errors while reading book or generating binbook
# -DGDBM use gdbm based book
# -DGDX  use random file based book
# -DNULLMOVE include null move heuristic
# some debug options
# -DDEBUG8 dump board,movelist,input move to /tmp/DEBUG if illegal move
# -DDEBUG9 dump move list from test command
# -DDEBUG10 dump board and move after search before !easy begins
# -DDEBUG11 dump board when the move is output
# -DDEBUG12 dump boards between moves
# -DDEBUG13 dump search control information for each move to /tmp/DEBUG
# -DDEBUG40 include extra values of variables for debugging  in game list
# -DDEBUG41 dump post output to /tmp/DEBUG
# the rest of the debug options are tied to the debuglevel command
# -DDEBUG -DDEBUG4 set up code for debuglevel command
#          debuglevel
#               1 always force evaluation in evaluate
#               4 print move list after search
#               8 print move list after book before search
#              16 print move list after each ply of search
#              32 print adds to transposition table
#              64 print returns from transposition table lookups
#	      256 print search tree as it is generated
#	      512 debug trace
#	     1024 interactive tree print
#			debug? p#  where # is no. of plys to print from top of tree (default all plys)
#			       XXXX moves specifying branch of tree to print (default all branches)
#			       return terminates input
#	     2048 non-interactive trace print

OPT = -DAG4 -DQUIETBACKGROUND -DNOSCORESPACE -DGNU3 -DHISTORY -DGDX \
      -DSEMIQUIETBOOKGEN -DNULLMOVE -DCACHE -DMSDOS -DHASINLINE

# The hashfile is a record of positions seen. It is used by
# GNU Chess to avoid making the same mistakes, a form of learning.
HASH = -DHASHFILE=\"$(LIBDIR)/gnuchess.has\"

# The "book" is a record of the first few moves, for playing good
# moves easily and quickly, saving time, and irritating the human
# opponent.
BOOK = -DBOOK=\"$(LIBDIR)/gnuchess.boo\"
BINBOOK = -DBINBOOK=\"$(LIBDIR)/gnuchess.dat\"

# The language file describes capabilities of the program. Perhaps
# it is useful for non-English speaking countries and customizing
# for their convenience and chess happiness.
LANG = -DLANGFILE=\"$(LIBDIR)/gnuchess.lan\"

# Gnu Chess options for easier reference
GNUCHESS = $(OPT) $(HASH) $(LANG) $(BOOK) $(BINBOOK)

# Configuration
# Select CPU, 0 - 8086, 1 - 80186, 2 - 80286
CPU = 0
# Select debug or release options
DEBUG = 0

#
# With Microsoft things tend to be rather complicated...  Look at
# this makefile.
#
# WARNING: The MSC 7.00 optimizer is broken!  Do NOT use the
# flags /Og and/or /Ob2.  With the current setting of the flags
# you will also encounter a compiler internal error when
# compiling search.c, but the compiler handles this gracefully
# (I hope...)
#
CC = cl
LINKER = link
LRF = echo > NUL
CFLAGS_G = /AL /W2 /BATCH /G$(CPU)
CFLAGS_D = /f /Zi /Od
CFLAGS_R = /f- /Ot /Oo /Ow /Oe /Oc /Ol /Gs
LFLAGS_G = /NOI /BATCH /ONERROR:NOEXE /FAR /PACKC /STACK:36864
LFLAGS_D = /CO
LFLAGS_R = /EXEPACK
!IF $(DEBUG)
CFLAGS = $(CFLAGS_G) $(CFLAGS_D)
LFLAGS = $(LFLAGS_G) $(LFLAGS_D)
!ELSE
CFLAGS = $(CFLAGS_G) $(CFLAGS_R)
LFLAGS = $(LFLAGS_G) $(LFLAGS_R)
!ENDIF

all : gnuchess.exe gnuchesr.exe gnuchesn.exe gnuchesc.exe postprin.exe gnuan.exe game.exe bincheck.exe checkgam.exe

gnuchess.exe: mainN.obj bookN.obj genmoveN.obj ataks.obj util.obj eval.obj init.obj searchN.obj dspcomN.obj uxdsp.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

gnuan.exe: mainN.obj bookN.obj genmoveN.obj ataks.obj util.obj eval.obj init.obj searchN.obj gnuan.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

gnuchesc.exe: mainC.obj bookC.obj genmoveC.obj ataks.obj util.obj eval.obj init.obj searchC.obj dspcomC.obj nondspC.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

gnuchesr.exe: mainN.obj bookN.obj genmoveN.obj ataks.obj util.obj eval.obj init.obj searchN.obj dspcomR.obj nondspR.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

gnuchesn.exe: mainN.obj bookN.obj genmoveN.obj ataks.obj util.obj eval.obj init.obj searchN.obj dspcomN.obj nuxdsp.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

game.exe: game.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

postprin.exe: postprin.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

bincheck.exe: bincheck.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

checkgam.exe: checkgam.obj
	$(LRF) @<<gnuchess.lrf
$(**: = +^
)
$@
$*
$(LIBS: = +^
)
$(DEF_FILE) $(LFLAGS);
<<
	$(LINKER) @gnuchess.lrf

mainN.obj: main.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ main.c
<<
mainC.obj: main.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP -DCHESSTOOL
/Fo$@ main.c
<<

genmoveN.obj: genmoves.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ genmoves.c
<<
genmoveC.obj: genmoves.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP -DCHESSTOOL
/Fo$@ genmoves.c
<<

bookN.obj: book.c gnuchess.h version.h ataks.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ book.c
<<
bookC.obj: book.c gnuchess.h version.h ataks.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP -DCHESSTOOL
/Fo$@ book.c
<<

ataks.obj: ataks.h ataks.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ ataks.c
<<

util.obj: util.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ util.c
<<

eval.obj: eval.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ eval.c
<<

init.obj: init.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ init.c
<<

searchN.obj: search.c gnuchess.h version.h debug512.h debug10.h debug13.h debug16.h debug256.h debug4.h debug40.h debug41.h debug64.h debug8.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ search.c
<<
searchC.obj: search.c gnuchess.h version.h debug512.h debug10.h debug13.h debug16.h debug256.h debug4.h debug40.h debug41.h debug64.h debug8.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP -DCHESSTOOL
/Fo$@ search.c
<<

uxdsp.obj: uxdsp.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ uxdsp.c
<<

nuxdsp.obj: nuxdsp.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ nuxdsp.c
<<

nondspC.obj: nondsp.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP -DCHESSTOOL
/Fo$@ nondsp.c
<<
nondspR.obj: nondsp.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP
/Fo$@ nondsp.c
<<

dspcomN.obj: dspcom.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ dspcom.c
<<
dspcomC.obj: dspcom.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP -DCHESSTOOL
/Fo$@ dspcom.c
<<
dspcomR.obj: dspcom.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS) -DNONDSP
/Fo$@ dspcom.c
<<

gnuan.obj: gnuan.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ gnuan.c
<<

game.obj: game.c gnuchess.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ game.c
<<

postprin.obj: postprin.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ postprin.c
<<

bincheck.obj: bincheck.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ bincheck.c
<<

checkgam.obj: checkgam.c gnuchess.h version.h
	@$(CC) @<<gnuchess.rsp
/c $(CFLAGS) $(GNUCHESS)
/Fo$@ checkgam.c
<<
